@@ -12,7 +12,7 @@ from urh.plugins.NetworkSDRInterface.NetworkSDRInterfacePlugin import NetworkSDR
 from urh.plugins.PluginManager import PluginManager
 from urh.ui.ui_send_recv_device_settings import Ui_FormDeviceSettings
 from urh.util.ProjectManager import ProjectManager
-
+import numpy as np
 
 class DeviceSettingsWidget(QWidget):
     selected_device_changed = pyqtSignal()
@@ -86,6 +86,8 @@ class DeviceSettingsWidget(QWidget):
         set_val(self.ui.spinBoxNRepeat, "num_sending_repeats",
                 constants.SETTINGS.value('num_sending_repeats', 1, type=int))
 
+        self.ui.lineEditSubdevice.setText(conf_dict.get("subdevice", ""))
+
         if self.rx_tx_prefix + "antenna_index" in conf_dict:
             self.ui.comboBoxAntenna.setCurrentIndex(conf_dict[self.rx_tx_prefix + "antenna_index"])
 
@@ -99,7 +101,7 @@ class DeviceSettingsWidget(QWidget):
             self.set_default_bb_gain()
 
         if self.is_rx:
-            checked = conf_dict.get("apply_dc_correction", False)
+            checked = conf_dict.get("apply_dc_correction", True)
             if isinstance(checked, str):
                 checked = True if checked == "True" else False
             self.ui.checkBoxDCCorrection.setChecked(checked)
@@ -143,6 +145,7 @@ class DeviceSettingsWidget(QWidget):
         self.ui.spinBoxBandwidth.editingFinished.connect(self.on_spinbox_bandwidth_editing_finished)
         self.ui.spinBoxPort.editingFinished.connect(self.on_spinbox_port_editing_finished)
         self.ui.lineEditIP.editingFinished.connect(self.on_line_edit_ip_editing_finished)
+        self.ui.lineEditSubdevice.editingFinished.connect(self.on_line_edit_subdevice_editing_finished)
 
         self.ui.comboBoxAntenna.currentIndexChanged.connect(self.on_combobox_antenna_current_index_changed)
         self.ui.comboBoxChannel.currentIndexChanged.connect(self.on_combobox_channel_current_index_changed)
@@ -171,7 +174,7 @@ class DeviceSettingsWidget(QWidget):
         prefix = self.rx_tx_prefix
         if prefix + "rf_gain" in conf:
             key = prefix + "rf_gain"
-            gain = conf[key][int(median(range(len(conf[key]))))]
+            gain = conf[key][int(np.percentile(range(len(conf[key])), 25))]
             self.ui.spinBoxGain.setValue(gain)
 
     def set_default_if_gain(self):
@@ -187,7 +190,7 @@ class DeviceSettingsWidget(QWidget):
         prefix = self.rx_tx_prefix
         if prefix + "baseband_gain" in conf:
             key = prefix + "baseband_gain"
-            baseband_gain = conf[key][int(median(range(len(conf[key]))))]
+            baseband_gain = conf[key][int(np.percentile(list(range(len(conf[key]))), 25))]
             self.ui.spinBoxBasebandGain.setValue(baseband_gain)
 
     def sync_gain_sliders(self):
@@ -225,6 +228,10 @@ class DeviceSettingsWidget(QWidget):
 
         self.ui.btnLockBWSR.setVisible("sample_rate" in conf and "bandwidth" in conf)
 
+        if self.device is not None:
+            self.ui.labelSubdevice.setVisible(self.device.subdevice is not None)
+            self.ui.lineEditSubdevice.setVisible(self.device.subdevice is not None)
+
         if "freq_correction" in conf:
             self.ui.labelFreqCorrection.setVisible(True)
             self.ui.spinBoxFreqCorrection.setVisible(True)
@@ -339,6 +346,7 @@ class DeviceSettingsWidget(QWidget):
         self.ui.spinBoxSampleRate.editingFinished.emit()
         self.ui.spinBoxFreqCorrection.editingFinished.emit()
         self.ui.lineEditIP.editingFinished.emit()
+        self.ui.lineEditSubdevice.editingFinished.emit()
         self.ui.spinBoxPort.editingFinished.emit()
         self.ui.comboBoxAntenna.currentIndexChanged.emit(self.ui.comboBoxAntenna.currentIndex())
         self.ui.comboBoxChannel.currentIndexChanged.emit(self.ui.comboBoxChannel.currentIndex())
@@ -347,7 +355,7 @@ class DeviceSettingsWidget(QWidget):
     def emit_device_parameters_changed(self):
         settings = {"name": str(self.device.name)}
         for attrib in ("frequency", "sample_rate", "bandwidth", "gain", "if_gain", "baseband_gain", "freq_correction",
-                       "antenna_index", "num_sending_repeats", "apply_dc_correction"):
+                       "antenna_index", "num_sending_repeats", "apply_dc_correction", "subdevice"):
             try:
                 value = getattr(self.device, attrib, None)
                 if value is not None:
@@ -392,6 +400,10 @@ class DeviceSettingsWidget(QWidget):
     def on_line_edit_ip_editing_finished(self):
         self.device.ip = self.ui.lineEditIP.text()
 
+    @pyqtSlot()
+    def on_line_edit_subdevice_editing_finished(self):
+        self.device.subdevice = self.ui.lineEditSubdevice.text()
+
     @pyqtSlot()
     def on_spinbox_port_editing_finished(self):
         self.device.port = self.ui.spinBoxPort.value()
