@@ -1,7 +1,7 @@
 from subprocess import call, Popen
 
-MODULES = ["path_creator", "signal_functions", "util"]
+MODULES = ["path_creator", "signal_functions", "util", "auto_interpretation"]
 
 for module in MODULES:
     call(["cython", "-a", "--cplus", "-3", module + ".pyx"])
-    Popen(["google-chrome-stable", module + ".html"])
+    Popen(["firefox", module + ".html"])
