@@ -6,10 +6,11 @@
 
 from PyQt5 import QtCore, QtGui, QtWidgets
 
+
 class Ui_DialogOptions(object):
     def setupUi(self, DialogOptions):
         DialogOptions.setObjectName("DialogOptions")
-        DialogOptions.resize(788, 822)
+        DialogOptions.resize(814, 822)
         icon = QtGui.QIcon.fromTheme("configure")
         DialogOptions.setWindowIcon(icon)
         self.verticalLayout_6 = QtWidgets.QVBoxLayout(DialogOptions)
@@ -18,26 +19,41 @@ class Ui_DialogOptions(object):
         self.tabWidget.setObjectName("tabWidget")
         self.tabGeneration = QtWidgets.QWidget()
         self.tabGeneration.setObjectName("tabGeneration")
-        self.layoutWidget = QtWidgets.QWidget(self.tabGeneration)
-        self.layoutWidget.setGeometry(QtCore.QRect(20, 20, 314, 99))
-        self.layoutWidget.setObjectName("layoutWidget")
-        self.gridLayout_4 = QtWidgets.QGridLayout(self.layoutWidget)
-        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
+        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.tabGeneration)
+        self.verticalLayout_9.setObjectName("verticalLayout_9")
+        self.gridLayout_4 = QtWidgets.QGridLayout()
         self.gridLayout_4.setObjectName("gridLayout_4")
-        self.labelFuzzingSamples = QtWidgets.QLabel(self.layoutWidget)
+        self.labelFuzzingSamples = QtWidgets.QLabel(self.tabGeneration)
         self.labelFuzzingSamples.setObjectName("labelFuzzingSamples")
         self.gridLayout_4.addWidget(self.labelFuzzingSamples, 1, 1, 1, 1)
-        self.checkBoxDefaultFuzzingPause = QtWidgets.QCheckBox(self.layoutWidget)
+        self.checkBoxDefaultFuzzingPause = QtWidgets.QCheckBox(self.tabGeneration)
         self.checkBoxDefaultFuzzingPause.setObjectName("checkBoxDefaultFuzzingPause")
         self.gridLayout_4.addWidget(self.checkBoxDefaultFuzzingPause, 0, 0, 1, 2)
-        self.doubleSpinBoxFuzzingPause = KillerDoubleSpinBox(self.layoutWidget)
+        self.doubleSpinBoxFuzzingPause = KillerDoubleSpinBox(self.tabGeneration)
         self.doubleSpinBoxFuzzingPause.setDecimals(3)
         self.doubleSpinBoxFuzzingPause.setMaximum(999999999.0)
         self.doubleSpinBoxFuzzingPause.setObjectName("doubleSpinBoxFuzzingPause")
         self.gridLayout_4.addWidget(self.doubleSpinBoxFuzzingPause, 1, 0, 1, 1)
-        self.checkBoxMultipleModulations = QtWidgets.QCheckBox(self.layoutWidget)
+        self.checkBoxMultipleModulations = QtWidgets.QCheckBox(self.tabGeneration)
         self.checkBoxMultipleModulations.setObjectName("checkBoxMultipleModulations")
         self.gridLayout_4.addWidget(self.checkBoxMultipleModulations, 2, 0, 1, 2)
+        self.verticalLayout_9.addLayout(self.gridLayout_4)
+        self.groupBoxModulationAccuracy = QtWidgets.QGroupBox(self.tabGeneration)
+        self.groupBoxModulationAccuracy.setObjectName("groupBoxModulationAccuracy")
+        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.groupBoxModulationAccuracy)
+        self.verticalLayout_7.setObjectName("verticalLayout_7")
+        self.radioButtonLowModulationAccuracy = QtWidgets.QRadioButton(self.groupBoxModulationAccuracy)
+        self.radioButtonLowModulationAccuracy.setObjectName("radioButtonLowModulationAccuracy")
+        self.verticalLayout_7.addWidget(self.radioButtonLowModulationAccuracy)
+        self.radioButtonMediumModulationAccuracy = QtWidgets.QRadioButton(self.groupBoxModulationAccuracy)
+        self.radioButtonMediumModulationAccuracy.setObjectName("radioButtonMediumModulationAccuracy")
+        self.verticalLayout_7.addWidget(self.radioButtonMediumModulationAccuracy)
+        self.radioButtonHighModulationAccuracy = QtWidgets.QRadioButton(self.groupBoxModulationAccuracy)
+        self.radioButtonHighModulationAccuracy.setObjectName("radioButtonHighModulationAccuracy")
+        self.verticalLayout_7.addWidget(self.radioButtonHighModulationAccuracy)
+        self.verticalLayout_9.addWidget(self.groupBoxModulationAccuracy)
+        spacerItem = QtWidgets.QSpacerItem(20, 500, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
+        self.verticalLayout_9.addItem(spacerItem)
         self.tabWidget.addTab(self.tabGeneration, "")
         self.tabView = QtWidgets.QWidget()
         self.tabView.setObjectName("tabView")
@@ -72,6 +88,18 @@ class Ui_DialogOptions(object):
         self.checkBoxAlignLabels = QtWidgets.QCheckBox(self.tabView)
         self.checkBoxAlignLabels.setObjectName("checkBoxAlignLabels")
         self.verticalLayout.addWidget(self.checkBoxAlignLabels)
+        self.horizontalLayout = QtWidgets.QHBoxLayout()
+        self.horizontalLayout.setObjectName("horizontalLayout")
+        self.labelFontSize = QtWidgets.QLabel(self.tabView)
+        self.labelFontSize.setObjectName("labelFontSize")
+        self.horizontalLayout.addWidget(self.labelFontSize)
+        self.spinBoxFontSize = QtWidgets.QSpinBox(self.tabView)
+        self.spinBoxFontSize.setMinimum(1)
+        self.spinBoxFontSize.setMaximum(120)
+        self.spinBoxFontSize.setProperty("value", 10)
+        self.spinBoxFontSize.setObjectName("spinBoxFontSize")
+        self.horizontalLayout.addWidget(self.spinBoxFontSize)
+        self.verticalLayout.addLayout(self.horizontalLayout)
         self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
         self.horizontalLayout_4.setObjectName("horizontalLayout_4")
         self.label_9 = QtWidgets.QLabel(self.tabView)
@@ -103,7 +131,7 @@ class Ui_DialogOptions(object):
         self.scrollAreaSpectrogramColormap.setWidgetResizable(True)
         self.scrollAreaSpectrogramColormap.setObjectName("scrollAreaSpectrogramColormap")
         self.scrollAreaWidgetSpectrogramColormapContents = QtWidgets.QWidget()
-        self.scrollAreaWidgetSpectrogramColormapContents.setGeometry(QtCore.QRect(0, 0, 708, 447))
+        self.scrollAreaWidgetSpectrogramColormapContents.setGeometry(QtCore.QRect(0, 0, 762, 397))
         self.scrollAreaWidgetSpectrogramColormapContents.setObjectName("scrollAreaWidgetSpectrogramColormapContents")
         self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetSpectrogramColormapContents)
         self.verticalLayout_4.setObjectName("verticalLayout_4")
@@ -133,12 +161,12 @@ class Ui_DialogOptions(object):
         self.btnRemoveLabeltype.setIcon(icon)
         self.btnRemoveLabeltype.setObjectName("btnRemoveLabeltype")
         self.verticalLayout_3.addWidget(self.btnRemoveLabeltype)
-        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
-        self.verticalLayout_3.addItem(spacerItem)
+        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
+        self.verticalLayout_3.addItem(spacerItem1)
         self.horizontalLayout_3.addLayout(self.verticalLayout_3)
         self.verticalLayout_5.addLayout(self.horizontalLayout_3)
-        spacerItem1 = QtWidgets.QSpacerItem(20, 203, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
-        self.verticalLayout_5.addItem(spacerItem1)
+        spacerItem2 = QtWidgets.QSpacerItem(20, 203, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
+        self.verticalLayout_5.addItem(spacerItem2)
         self.tabWidget.addTab(self.tabFieldtypes, "")
         self.tab_plugins = QtWidgets.QWidget()
         self.tab_plugins.setObjectName("tab_plugins")
@@ -272,7 +300,7 @@ class Ui_DialogOptions(object):
         self.verticalLayout_6.addWidget(self.tabWidget)
 
         self.retranslateUi(DialogOptions)
-        self.tabWidget.setCurrentIndex(4)
+        self.tabWidget.setCurrentIndex(0)
 
     def retranslateUi(self, DialogOptions):
         _translate = QtCore.QCoreApplication.translate
@@ -281,6 +309,10 @@ class Ui_DialogOptions(object):
         self.checkBoxDefaultFuzzingPause.setToolTip(_translate("DialogOptions", "<html><head/><body><p>If you disable the default pause, the pause of the fuzzed message will be used.</p></body></html>"))
         self.checkBoxDefaultFuzzingPause.setText(_translate("DialogOptions", "Use a default pause for fuzzed messages"))
         self.checkBoxMultipleModulations.setText(_translate("DialogOptions", "Enable modulation profiles"))
+        self.groupBoxModulationAccuracy.setTitle(_translate("DialogOptions", "Modulation Accuracy"))
+        self.radioButtonLowModulationAccuracy.setText(_translate("DialogOptions", "Low (2x8 bit) - Recommended for HackRF and RTL-SDR"))
+        self.radioButtonMediumModulationAccuracy.setText(_translate("DialogOptions", "Medium (2x16 bit) - Recommended for BladeRF, PlutoSDR and SDRPlay"))
+        self.radioButtonHighModulationAccuracy.setText(_translate("DialogOptions", "High (2x32 bit) - Recommended if you are not sure what to choose"))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabGeneration), _translate("DialogOptions", "Generation"))
         self.label_7.setText(_translate("DialogOptions", "Default View:"))
         self.comboBoxDefaultView.setItemText(0, _translate("DialogOptions", "Bit"))
@@ -291,6 +323,8 @@ class Ui_DialogOptions(object):
         self.checkBoxHoldShiftToDrag.setText(_translate("DialogOptions", "Hold shift to drag"))
         self.checkBoxPauseTime.setText(_translate("DialogOptions", "Show pauses as time"))
         self.checkBoxAlignLabels.setText(_translate("DialogOptions", "Align on labels"))
+        self.labelFontSize.setText(_translate("DialogOptions", "<html><head/><body><p>Application font size (<span style=\" font-weight:600;\">restart</span> for full effect):</p></body></html>"))
+        self.spinBoxFontSize.setSuffix(_translate("DialogOptions", "pt"))
         self.label_9.setText(_translate("DialogOptions", "Choose application theme (requires restart):"))
         self.comboBoxTheme.setItemText(0, _translate("DialogOptions", "native look (default)"))
         self.comboBoxTheme.setItemText(1, _translate("DialogOptions", "fallback theme"))
@@ -333,4 +367,5 @@ class Ui_DialogOptions(object):
         self.doubleSpinBoxRAMThreshold.setSuffix(_translate("DialogOptions", "%"))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabDevices), _translate("DialogOptions", "Device"))
 
+
 from urh.ui.KillerDoubleSpinBox import KillerDoubleSpinBox
