@@ -153,7 +153,6 @@ class ProjectManager(QObject):
 
         self.decodings = decodings if decodings else fallback
 
-
     @staticmethod
     def read_device_conf_dict(tag: ET.Element, target_dict):
         if tag is None:
@@ -161,10 +160,17 @@ class ProjectManager(QObject):
 
         for dev_tag in tag:
             try:
-                value = float(dev_tag.text)
+                try:
+                    value = int(dev_tag.text)
+                except ValueError:
+                    value = float(dev_tag.text)
             except ValueError:
                 value = dev_tag.text
-            target_dict[dev_tag.tag] = value
+
+            if dev_tag.tag == "bit_len":
+                target_dict["samples_per_symbol"] = value   # legacy
+            else:
+                target_dict[dev_tag.tag] = value
 
     @staticmethod
     def __device_conf_dict_to_xml(key_name: str, device_conf: dict):
@@ -295,16 +301,23 @@ class ProjectManager(QObject):
         for signal_tag in root.iter("signal"):
             existing_filenames[signal_tag.attrib["filename"]] = signal_tag
 
-        if os.path.relpath(signal.filename, self.project_path) in existing_filenames.keys():
-            signal_tag = existing_filenames[os.path.relpath(signal.filename, self.project_path)]
+        try:
+            file_path = os.path.relpath(signal.filename, self.project_path)
+        except ValueError:
+            # Can happen e.g. on Windows when Project is in C:\ and signal on D:\
+            file_path = signal.filename
+
+        if file_path in existing_filenames.keys():
+            signal_tag = existing_filenames[file_path]
         else:
             # Create new tag
             signal_tag = ET.SubElement(root, "signal")
 
         signal_tag.set("name", signal.name)
-        signal_tag.set("filename", os.path.relpath(signal.filename, self.project_path))
-        signal_tag.set("bit_length", str(signal.bit_len))
-        signal_tag.set("qad_center", str(signal.qad_center))
+        signal_tag.set("filename", file_path)
+        signal_tag.set("samples_per_symbol", str(signal.samples_per_symbol))
+        signal_tag.set("center", str(signal.center))
+        signal_tag.set("center_spacing", str(signal.center_spacing))
         signal_tag.set("tolerance", str(signal.tolerance))
         signal_tag.set("noise_threshold", str(signal.noise_threshold))
         signal_tag.set("noise_minimum", str(signal.noise_min_plot))
@@ -313,6 +326,7 @@ class ProjectManager(QObject):
         signal_tag.set("sample_rate", str(signal.sample_rate))
         signal_tag.set("pause_threshold", str(signal.pause_threshold))
         signal_tag.set("message_length_divisor", str(signal.message_length_divisor))
+        signal_tag.set("bits_per_symbol", str(signal.bits_per_symbol))
 
         messages = ET.SubElement(signal_tag, "messages")
         for message in messages:
@@ -392,7 +406,12 @@ class ProjectManager(QObject):
                 open_files.append(open_filename)
 
                 file_tag = ET.SubElement(root, "open_file")
-                file_tag.set("name", os.path.relpath(open_filename, self.project_path))
+                try:
+                    file_path = os.path.relpath(open_filename, self.project_path)
+                except ValueError:
+                    file_path = open_filename
+
+                file_tag.set("name", file_path)
                 file_tag.set("position", str(i))
             except Exception:
                 pass
@@ -410,7 +429,12 @@ class ProjectManager(QObject):
             for proto_frame in cfc.protocols[i]:
                 if proto_frame.filename:
                     proto_tag = ET.SubElement(group_tag, "cf_protocol")
-                    proto_tag.set("filename", os.path.relpath(proto_frame.filename, self.project_path))
+                    try:
+                        rel_file_name = os.path.relpath(proto_frame.filename, self.project_path)
+                    except ValueError:
+                        rel_file_name = proto_frame.filename
+
+                    proto_tag.set("filename", rel_file_name)
 
         root.append(cfc.proto_analyzer.to_xml_tag(decodings=cfc.decodings, participants=self.participants,
                                                   messages=[msg for proto in cfc.full_protocol_list for msg in
@@ -428,8 +452,13 @@ class ProjectManager(QObject):
         tree = ET.parse(self.project_file)
         root = tree.getroot()
 
+        try:
+            signal_filename = os.path.relpath(signal.filename, self.project_path)
+        except ValueError:
+            signal_filename = signal.filename
+
         for sig_tag in root.iter("signal"):
-            if sig_tag.attrib["filename"] == os.path.relpath(signal.filename, self.project_path):
+            if sig_tag.attrib["filename"] == signal_filename:
                 messages_tag = sig_tag.find("messages")
 
                 try:
@@ -449,17 +478,32 @@ class ProjectManager(QObject):
 
         tree = ET.parse(self.project_file)
         root = tree.getroot()
+
+        try:
+            signal_filename = os.path.relpath(signal.filename, self.project_path)
+        except ValueError:
+            signal_filename = signal.filename
+
         for sig_tag in root.iter("signal"):
-            if sig_tag.attrib["filename"] == os.path.relpath(signal.filename,
-                                                             self.project_path):
+            if sig_tag.attrib["filename"] == signal_filename:
                 signal.name = sig_tag.attrib["name"]
-                signal.qad_center = float(sig_tag.get("qad_center", 0))
+                center = sig_tag.get("qad_center", None)  # legacy support
+                signal.center = float(sig_tag.get("center", 0)) if center is None else float(center)
+                signal.center_spacing = float(sig_tag.get("center_spacing", 0.1))
                 signal.tolerance = int(sig_tag.get("tolerance", 5))
+                signal.bits_per_symbol = int(sig_tag.get("bits_per_symbol", 1))
 
                 signal.noise_threshold = float(sig_tag.get("noise_threshold", 0.1))
                 signal.sample_rate = float(sig_tag.get("sample_rate", 1e6))
-                signal.bit_len = int(sig_tag.get("bit_length", 100))
-                signal.modulation_type = int(sig_tag.get("modulation_type", 0))
+                signal.samples_per_symbol = int(sig_tag.get("bit_length", 0))   # Legacy for old project files
+                if signal.samples_per_symbol == 0:
+                    signal.samples_per_symbol = int(sig_tag.get("samples_per_symbol", 100))
+
+                try:
+                    # Legacy support when modulation type was integer
+                    signal.modulation_type = Signal.MODULATION_TYPES[int(sig_tag.get("modulation_type", 0))]
+                except (ValueError, IndexError):
+                    signal.modulation_type = sig_tag.get("modulation_type", "ASK")
                 signal.pause_threshold = int(sig_tag.get("pause_threshold", 8))
                 signal.message_length_divisor = int(sig_tag.get("message_length_divisor", 1))
                 break
@@ -474,7 +518,9 @@ class ProjectManager(QObject):
 
             for file_tag in root.findall("open_file"):
                 pos = int(file_tag.attrib["position"])
-                filename = os.path.normpath(os.path.join(self.project_path, file_tag.attrib["name"]))
+                filename = file_tag.attrib["name"]
+                if not os.path.isfile(filename):
+                    filename = os.path.normpath(os.path.join(self.project_path, filename))
                 file_names.insert(pos, filename)
 
             QApplication.setOverrideCursor(Qt.WaitCursor)
@@ -501,7 +547,9 @@ class ProjectManager(QObject):
             group = tree_root.child(int(id))
 
             for proto_tag in group_tag.iter("cf_protocol"):
-                filename = os.path.normpath(os.path.join(self.project_path, proto_tag.attrib["filename"]))
+                filename = proto_tag.attrib["filename"]
+                if not os.path.isfile(filename):
+                    filename = os.path.normpath(os.path.join(self.project_path, filename))
                 try:
                     proto_frame_item = next((p for p in proto_frame_items if p.protocol.filename == filename))
                 except StopIteration:
